@@ -649,7 +649,7 @@ http://www.d.umn.edu/~tpederse/Pubs/eacl2006-vector.pdf
 --indexfile and --matrixfile option. The co-occurrence matrix and index
 file used in the vector method are prepared by vector-input.pl method. 
 Index file assigns each term of the bigrams a number and also records the 
-vector position and length which starts the term of the co-occrrence matrix. 
+vector position and length which starts the term of the co-occurrence matrix. 
 For example, for the following bigrams list which are generated by the 
 text "This is the first line Of a LONG file.":
 
@@ -695,7 +695,7 @@ matrix. For example, the first line of the matrix file "2: 6 1" means
 for the term '2' which is 'LONG', it has a bigram pair with term 
 '6' which is 'file', and the frequency is 1. In the index file, for 
 the term 'LONG', it use '2' to represent 'LONG' and it starts at the 
-'0' position of the file(byte) and the vector has lenghth '8'. The 
+'0' position of the file(byte) and the vector has length '8'. The 
 vector-input.pl requires the bigrams are sorted, and you could use 
 count2huge.pl method of Text-NSP to convert the output of count.pl 
 to huge-count.pl. 
@@ -711,7 +711,7 @@ than the definitions from the UMLS.
 --stoplist option is a word list file for the vector measure. The words
 in the file should be removed from the definition. In the stop list file, 
 each word is in the regular expression format. A stop word sample file 
-is under the samples folder which is called toplist-nsp.regex.
+is under the samples folder which is called stoplist-nsp.regex.
 
 --stem option is a flag for the vector measure. If we the --stem flag
 is set, the words of the definition are stemmed by the the Porter Stemming
@@ -745,6 +745,40 @@ the following piece of code:
 
    $relatedness = $measure->getRelatedness('C0005767', 'C0007634');
 
+=head1 CONFIGURATION OPTION
+
+The UMLS-Interface package takes a configuration file to determine 
+which sources and relations to use when obtaining the extended 
+definitions. We call the definition used by the measure, the extended 
+definition because this may include definitions from related concepts. 
+
+The format of the configuration file is as follows:
+
+SABDEF :: <include|exclude> <source1, source2, ... sourceN>
+
+RELDEF :: <include|exclude> <relation1, relation2, ... relationN>
+
+For example, if we wanted to use the definitions from MSH vocabulary 
+and we only wanted the definition of the CUI and the definitions of the 
+CUIs SIB relation, the configuration file would be:
+
+SABDEF :: include MSH
+RELDEF :: include CUI, SIB
+
+Note: RELDEF takes any of MRREL relations and two special 'relations':
+
+      1. CUI which refers to the CUIs definition
+
+      2. TERM which refers to the terms associated with the CUI
+
+
+If you go to the configuration file directory, there will 
+be example configuration files for the different runs that 
+you have performed.
+
+For more information about the configuration options please 
+see the README.
+
 =head1 SEE ALSO
 
 perl(1), UMLS::Interface
